use config::Config;
use crate::settings;
use crate::transcoder::repository::Repository;

pub fn setup_command() {
  // load configuration
  let c: Config = settings::load_config();

  // resolve repository path
  let repository_dir_raw: &str = &c.get_string("transcoder.repository").unwrap();
  let repository_dir: &str = &shellexpand::tilde(repository_dir_raw);

  // alert the user to what's happening
  println!("Initializing video repository at {}...", repository_dir);

  // create and initialize our repository object
  let r: Repository = Repository::new(repository_dir);
  // initialize the video repository
  r.initialize();
}

pub fn version_command() {
  println!("===================================================================================");

  // output the program and version
  println!("Zealot version v{}", env!("CARGO_PKG_VERSION"));

  // output project description
  println!("{}", env!("CARGO_PKG_DESCRIPTION"));

  // display license info
  println!("\nThis code is licensed under the {} license.", env!("CARGO_PKG_LICENSE"));

  // output the project source URL
  println!("View the source code or file issues at {}.", env!("CARGO_PKG_REPOSITORY"));

  println!("===================================================================================");
}
